# Changelog

All notable changes to this project will be documented in this file.

## [0.1.1] - 2024-08-11

### 🚀 Features

- Add support for litestream logging and metrics

### 🐛 Bug Fixes

- Exec is optional

### 📚 Documentation

- Minimal doc

## [0.1.0] - 2024-08-11

### 🐛 Bug Fixes

- Broken exec argument
- Missing argument to wal

### 🚜 Refactor

- Remove useless code
- Extend is more explicit

### ⚙️ Miscellaneous Tasks

- Configure bumpver and cliff

<!-- generated by git-cliff -->
